User Guide — mriqc 0.8 documentation

# User Guide

# Contents

- The MRIQC Reports
  - Structural images (sMRI)
    - For the individual scan reports:
    - For the group reports:
  - Functional images (fMRI)
- mriqc.reports package
  - Submodules
  - mriqc.reports.generators module
  - mriqc.reports.utils module
  - Module contents

## Installation

We have included `mriqc` in the PyPi resource

    pip install mriqc

## Dependencies

If you are using a linux distribution with neurodebian, installation should be as easy as:

    sudo apt-get fsl afni ants
    sudo ln -sf /usr/lib/ants/N4BiasFieldCorrection /usr/local/bin/

After installation, make sure that all the necessary binaries are added to the `$PATH` environment variable, for the profile used run `mriqc`.

Otherwise, you can follow each software installation guide: FSL, AFNI, and ANTs.

## Running mriqc

The software automatically finds the data the input folder if it follows the BIDS standard [BIDS]. A fast and easy way to check that your dataset fulfills the BIDS standard is the BIDS validator.

Running `mriqc` only requires:

    mriqc -B ~/Data/bids_dataset -o out/ -w work/

It is possible to run `mriqc` on specific subjects using

    mriqc -B ~/Data/bids_dataset -S S001 S002 -o out/ -w work/

where `S001` and `S002` are subject identifiers, corresponding to the folders `sub-S001` and `sub-S002` in the BIDS tree. Here, it is also accepted to use the `sub-` prefix

    mriqc -B ~/Data/bids_dataset -S sub-S001 sub-S002 -o out/ -w work/

Depending on the input images, the resulting outputs will vary as described next.

> [BIDS] | Brain Imaging Data Structure